@@ -49,7 +49,7 @@ use File::Spec ();
 # Globals
 use vars qw{$VERSION $RE_IDENTIFIER $RE_CLASS $UNIX};
 BEGIN {
-	$VERSION = '1.25';
+	$VERSION = '1.27';
 
 	# If Unicode is available, enable it so that the
 	# pattern matches below match unicode method names.
@@ -124,7 +124,7 @@ sub _loaded {
 	# Handle by far the two most common cases
 	# This is very fast and handles 99% of cases.
 	return 1 if defined ${"${name}::VERSION"};
-	return 1 if defined @{"${name}::ISA"};
+	return 1 if @{"${name}::ISA"};
 
 	# Are there any symbol table entries other than other namespaces
 	foreach ( keys %{"${name}::"} ) {
@@ -627,7 +627,7 @@ L<http://ali.as/>, L<Class::Handle>
 
 =head1 COPYRIGHT
 
-Copyright 2002 - 2011 Adam Kennedy.
+Copyright 2002 - 2012 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
